
# Slot: base


python base type that implements this type definition

URI: [meta:base](https://w3id.org/biolink/biolinkml/meta/base)

## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [String](String.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)
